#ifndef DEBTAGS_BASIC_PACKAGE_FILTER_H
#define DEBTAGS_BASIC_PACKAGE_FILTER_H

#pragma interface

#include <string>
#include <tagcoll/Tag.h>
#include <tagcoll/TagSet.h>
#include <debtags/Consumer.h>

namespace Debtags
{

using namespace Tagcoll;

class Package;
class Regexp;

class BasicPackageMatcher : public PackageMatcher
{
public:
	typedef enum { YES, NO, ANY } InstalledStatus;
protected:
	std::string maint;
	Regexp* name;
	Regexp* str;
	InstalledStatus installed;
	TagSet tags;

public:
	BasicPackageMatcher() throw ()
		: name(0), str(0), installed(ANY) {}
	virtual ~BasicPackageMatcher() throw ();

	void setName(const std::string _name) throw ();
	void setMaintainer(const std::string _maint) throw () { maint = _maint; }
	void setString(const std::string _str) throw ();
	void setInstalled(InstalledStatus val) throw ()
	{
		installed = val;
	}
	void setDebtags(const TagSet& ptags) throw ()
	{
		tags = ptags;
	}

	bool hasName() const throw () { return name != 0; }
	bool hasMaintainer() const throw () { return !maint.empty(); }
	bool hasString() const throw () { return str != 0; }
	bool hasInstalled() const throw () { return installed != ANY; }
	bool hasDebtags() const throw () { return !tags.empty(); }

	// Compute values useful in deciding search strategies
	bool hasOnlyName() const throw () { return name != 0 && str == 0 && maint.empty() && installed == ANY && tags.empty(); }
	bool hasOnlyMaintainer() const throw () { return name == 0 && str == 0 && !maint.empty() && installed == ANY && tags.empty(); }
	bool isMaintainerSignificant() const throw () { return maint.size() > 1; }
	bool hasOnlyDebtags() const throw () { return name == 0 && str == 0 && maint.empty() && installed == ANY && !tags.empty(); }
	bool hasNonDebtags() const throw () { return name != 0 || str != 0 || !maint.empty() || installed != ANY; }

	bool matchName(const std::string& text) const throw ();
	bool matchMaintainer(const std::string& text) const throw ();
	bool matchString(const std::string& text) const throw ();
	bool matchInstalled(int status) const throw ();
	bool matchDebtags(const TagSet& ptags) const throw ();
	const TagSet& debtagsTagset() const throw () { return tags; }

	bool match(const Package& pkg) const throw ();
};

};

// vim:set ts=3 sw=3:
#endif
