#ifndef DEBTAGS_CONSUMER_H
#define DEBTAGS_CONSUMER_H

/*
 * Package stream consumer and filter interfaces
 *
 * Copyright (C) 2003  Enrico Zini <enrico@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

//#pragma interface

#include <tagcoll/TagConsumer.h>
#include <string>

namespace Tagcoll
{
class Facet;
class Tag;
class TagSet;
};

namespace Debtags
{
using namespace Tagcoll;

class Package;
class Maintainer;

typedef Consumer<Package> PackageConsumer;
typedef Consumer<Maintainer> MaintainerConsumer;

class PackageMatcher : public Matcher<Package>
{
public:
	// Compute values useful in deciding search strategies
	virtual bool hasDebtags() const throw () = 0;
	virtual bool hasOnlyName() const throw () = 0;
	virtual bool hasOnlyMaintainer() const throw () = 0;
	virtual bool isMaintainerSignificant() const throw () = 0;
	virtual bool hasOnlyDebtags() const throw () = 0;
	virtual bool hasNonDebtags() const throw () = 0;

	// Partial matches useful in optimized searches
	virtual bool matchName(const std::string& text) const throw () = 0;
	virtual bool matchMaintainer(const std::string& text) const throw () = 0;
	virtual const TagSet& debtagsTagset() const throw () = 0;
};

class MaintainerMatcher : public Matcher<Maintainer> {};


class PackageFilter : public Filter<Package>
{
    PackageFilter(PackageConsumer& next) throw () : Filter<Package>(next) {}
};

class MaintainerFilter : public Filter<Maintainer>
{
public:
    MaintainerFilter(MaintainerConsumer& next) throw () : Filter<Maintainer>(next) {}
};


class PackageMatcherFilter : public MatcherFilter<Package>
{
public:
	PackageMatcherFilter(PackageMatcher& matcher, PackageConsumer& next) throw ()
		: MatcherFilter<Package>(matcher, next) {}
};

class MaintainerMatcherFilter : public MatcherFilter<Maintainer>
{
public:
	MaintainerMatcherFilter(MaintainerMatcher& matcher, MaintainerConsumer& next) throw ()
		: MatcherFilter<Maintainer>(matcher, next) {}
};

};

// vim:set ts=4 sw=4:
#endif
