#ifndef DEBTAGS_MAINTAINER_SET_H
#define DEBTAGS_MAINTAINER_SET_H

/*
 * Central class to perform package searches
 *
 * Copyright (C) 2003  Enrico Zini <enrico@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#pragma interface

#include <tagcoll/OpSet.h>
#include <debtags/Maintainer.h>

namespace Tagcoll
{
class FacetSet;
class TagSet;
};

namespace Debtags
{
using namespace Tagcoll;
class PackageSet;

class MaintainerSet : public OpSet<Debtags::Maintainer>
{
public:
	using OpSet<Debtags::Maintainer>::find;

	MaintainerSet() throw ();
	MaintainerSet(const OpSet<Debtags::Maintainer>&) throw ();
	~MaintainerSet() throw ();

	// Get the Maintainer object given the package name
	Maintainer find(const std::string& name) const throw ();

	// Get all the packages maintained by these maintainers
	PackageSet getPackages() const throw ();

	// Get all the facets of the tags of the packages maintained by these maintainers
	FacetSet getFacets() const throw ();

	// Get all the tags of the packages maintained by these maintainers
	TagSet getTags() const throw ();
};

};

// vim:set ts=4 sw=4:
#endif
