#ifndef DEBTAGS_PACKAGE_H
#define DEBTAGS_PACKAGE_H

#pragma interface

#include "PackageDB.h"

#include <string>

namespace Tagcoll
{
class Tag;
class TagSet;
};

namespace Debtags
{
using namespace Tagcoll;

class AvailableReader;
class StandardEnvironment;
class PackageImpl;
class PackageSet;
class Maintainer;

class Package
{
protected:
	PackageImpl* impl;

	explicit Package(PackageImpl* existing_impl) throw ();

public:
	Package() throw ();
	explicit Package(const std::string& name) throw ();
	Package(const Package& f) throw ();
	~Package() throw ();
	Package& operator=(const Package& f) throw ();

	bool operator==(const Package& f) const throw ();
	bool operator<(const Package& f) const throw ();

	operator bool() const throw ();

	const std::string& name() const throw ();

	const std::string& sdesc() const throw ();
	const std::string& ldesc() const throw ();
	const Maintainer& maint() const throw ();
	int state() const throw (PackageDBException);

	const std::string& sdesc(const std::string& sdesc) throw ();
	const std::string& ldesc(const std::string& ldesc) throw ();
	const Maintainer& maint(const Maintainer& maint) throw ();
	const std::string& fulldata(const std::string& fulldata) throw ();

	const TagSet tags() const throw ();
	const std::string& fulldata() const throw ();

	friend class PackageSet;
	friend class PackageImpl;
	friend class AvailableReader;
	friend class StandardEnvironment;
};

};

// vim:set ts=3 sw=3:
#endif
