#ifndef PACKAGEDB_H
#define PACKAGEDB_H

/*
 * Wrapper around libapt-pkg
 *
 * Copyright (C) 2003  Enrico Zini <enrico@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <tagcoll/Exception.h>
#include <apt-pkg/pkgrecords.h>
#include <string>

class pkgTagSection;

namespace Debtags {

class PackageDBException : public ContextException
{
public:
	PackageDBException(const std::string& context) throw ()
		: ContextException(context) {}
	~PackageDBException() throw () {}

	virtual const char* type() const throw ()
	{
		return "PackageDBException";
	}
};

class PackageDBImpl;

class PkgRecordConsumer
{
public:
	virtual void operator()(pkgRecords::Parser&) = 0;
};

class PackageDB
{
protected:
	PackageDBImpl* impl;
	
public:
	PackageDB() throw (PackageDBException);
	PackageDB(const PackageDB& f) throw ();
	~PackageDB() throw ();
	PackageDB& operator=(const PackageDB& f) throw ();

	bool hasPackage(const std::string& pkg) const throw ();
	
	std::string getPackageRecord(const std::string& pkg) const throw (PackageDBException);
	void getPackageRecord(const std::string& pkg, pkgTagSection& section) const
		throw (PackageDBException);

	int getState(const std::string& pkg) const throw (PackageDBException);

	void iterateAll(PkgRecordConsumer& consume) const throw (PackageDBException);
};

};

// vim:set ts=4 sw=4:
#endif
