#ifndef DEBTAGS_PACKAGE_SET_H
#define DEBTAGS_PACKAGE_SET_H

/*
 * Central class to perform package searches
 *
 * Copyright (C) 2003  Enrico Zini <enrico@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#pragma interface

#include <debtags/Package.h>
#include <debtags/Consumer.h>

#include <tagcoll/OpSet.h>

namespace Tagcoll
{
class FacetSet;
class TagSet;
};

namespace Debtags
{
using namespace Tagcoll;
class Maintainer;
class MaintainerSet;

class PackageSet : public OpSet<Debtags::Package>, public PackageConsumer
{
public:
	using OpSet<Debtags::Package>::find;

	PackageSet() throw ();
	PackageSet(const OpSet<Debtags::Package>&) throw ();
	virtual ~PackageSet() throw ();

	virtual void consume(const Package& pkg) throw ();

	// Get a list of all facets in these packages
	FacetSet getFacets() const throw ();

	// Get a list of all tags in these packages
	TagSet getTags() const throw ();

	// Get a list of all the maintainers of these packages
	MaintainerSet getMaintainers() const throw ();

	// Get the set of all tags in this collection that appear in tagsets
	// containing `ts'
	Debtags::TagSet getCompanionTags(const Debtags::TagSet& ts) const throw ();

	// Get the Package object given the package name
	Package find(const std::string& name) const throw ();

	// Get the Maintainer object given the maintainers's e-mail
	Maintainer findMaintainer(const std::string& email) const throw ();

	// Output the whole package list to `cons'
	void output(PackageConsumer& cons) const throw ();

	// Output the filtered package list to `cons'
	void output(PackageConsumer& cons, PackageMatcher& filter) const throw ();

	// Get the packages that are matched by `filter'
	PackageSet getFiltered(PackageMatcher& filter) const throw ();

	// Get the PackageSet of packages related to `pivot'
	PackageSet getRelated(const Package& pivot, int distance = 1) const throw ();

	// Get the PackageSet of packages related to the specific tagset
	PackageSet getRelated(const Debtags::TagSet& ts, int distance = 1) const throw ();

	// Output list of packages related to `pivot' to `cons'
	void outputRelated(PackageConsumer& cons, const Package& pivot, int distance = 1) const throw ();

	// Output list of packages related to the specific tagset to `cons'
	void outputRelated(PackageConsumer& cons, const Debtags::TagSet& ts, int distance = 1) const throw ();
};

};

// vim:set ts=4 sw=4:
#endif
