#ifndef VOCABULARY_H
#define VOCABULARY_H

/*
 * Tag vocabulary access
 *
 * Copyright (C) 2003  Enrico Zini <enrico@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <tagcoll/TagSet.h>
#include <tagcoll/TagConsumer.h>
#include <tagcoll/ParserBase.h>
#include <tagcoll/DerivedTags.h>

#include <string>
#include <list>
#include <map>

namespace Tagcoll
{
class Facet;
class FacetConsumer;
class FacetFilter;
class TagConsumer;
class TagFilter;
};

namespace Debtags
{
using namespace Tagcoll;

class Vocabulary : public FacetSet
{
protected:
	DerivedTagList equations;
	
public:
	/// Get the DerivedTagList with the Equates: expressions read from the vocabulary
	const DerivedTagList& getEquations() const throw () { return equations; }
	
	/// Check if the vocabulary contains the facet `facet'
	bool hasFacet(const std::string& facet) const throw () { return has(facet); }

	/// Return the facet with the given name
	Facet findFacet(const std::string& facet) const throw () { return find(facet); }

	/// Get a set with all the facets present in the vocabulary
	const FacetSet& getFacets() const throw () { return *this; }
	
	/// Get a set with all the facets present in the vocabulary that are matched by `filter'
	FacetSet getFacets(const FacetMatcher& filter) const throw () { return getFiltered(filter); }

	/// Parse and import the vocabulary from `input'
	void read(ParserInput& input) throw (ParserException);

	/// Parse and import the system vocabulary
	void read() throw (FileException, ParserException);

	/// Obsolete function
	void readVocabularies() throw (SystemException, FileException, ParserException);

	/// Write the contents of this vocabulary to the system vocabulary
	void write() throw (FileException);

	/*
	void outputImplications(TagcollConsumer<std::string>& consumer) const throw ();
	void outputDerivedTags(DerivedTagList& dtlist) const throw ();
	*/
};

};

// vim:set ts=4 sw=4:
#endif
